import "@/app/globals.css";
import Footer from "@/components/Footer";
import Header from "@/components/Header";
import InitialScript from "@/components/InitialScript";
import { navMenuData } from "@/data/menu";
import { getDefaultMetadata } from "@/utils/metadata";

import "@public/assets/css/styles.css";
import "jarallax/dist/jarallax.min.css";
import { Metadata } from "next";
import { Roboto, Noto_Sans } from "next/font/google";
import "photoswipe/dist/photoswipe.css";
import "react-modal-video/css/modal-video.css";
import "swiper/css";
import "swiper/css/effect-fade";
import "tippy.js/dist/tippy.css";

const roboto = Roboto({
  weight: ["400", "500", "600", "700", "800"],
  style: ["normal", "italic"],
  subsets: ["latin"],
  display: "swap",
  variable: "--font-roboto",
});
const notoSans = Noto_Sans({
  weight: ["400", "500", "600"],
  style: ["normal", "italic"],
  subsets: ["latin"],
  display: "swap",
  variable: "--font-noto-sans",
});

export async function generateMetadata(): Promise<Metadata> {
  const metadata = await getDefaultMetadata();
  return metadata;
}

export default function MainLayout({
  children,
}: Readonly<{
  children: React.ReactNode;
}>) {
  return (
    <html lang="en" className={`no-mobile no-touch ${roboto.variable} ${notoSans.variable}`}>
      <InitialScript />
      <body className="appear-animate body font-fontMain">
        <div className="theme-slick">
          <div className="page" id="top">
            <Header links={navMenuData} />
            <main id="main">{children}</main>
            <Footer />
          </div>
        </div>
      </body>
    </html>
  );
}
