import Homepage from "@/components/Homepage";
import { BeforeFooterBlock } from "@/components/Blocks/BeforeFooter";
import { Metadata, Viewport } from "next";
import { getDefaultMetadata } from "@/utils/metadata";
import HomeBgVideo from "@/components/HomeBgVideo";
import { headers } from "next/headers";

export async function generateMetadata(): Promise<Metadata> {
  const defaultMetadata = await getDefaultMetadata();
  defaultMetadata.title = `Homepage - ${defaultMetadata.openGraph?.siteName}`;
  defaultMetadata.keywords = "Cochise Oncology, Oncology, Healthcare, Medical Services, Cancer Treatment";

  if (!!defaultMetadata?.openGraph) {
    defaultMetadata.openGraph.images = ["/assets/images/cochise-welcome.png"];
  }

  return defaultMetadata;
}

export const viewport: Viewport = {
  width: "device-width",
  initialScale: 1,
};

export default async function Home() {
  const headersList = await headers();
  const fullUrl = headersList.get("x-full-url");
  const siteName = headersList.get("x-site-name");
  const metaDesc = headersList.get("x-meta-desc");

  const jsonLd = {
    "@context": "https://schema.org",
    "@graph": [
      {
        "@type": "WebPage",
        "@id": fullUrl,
        url: fullUrl,
        name: `Homepage - ${siteName}`,
        isPartOf: {
          "@id": `${fullUrl}#website`,
        },
        about: {
          "@id": `${fullUrl}#organization`,
        },
        primaryImageOfPage: {
          "@id": `${fullUrl}#primaryimage`,
        },
        image: {
          "@id": `${fullUrl}#primaryimage`,
        },
        thumbnailUrl: [`${fullUrl}assets/images/cochise-welcome.png`],
        datePublished: "2024-07-18T16:29:29+00:00",
        dateModified: "2025-02-24T21:01:50+00:00",
        description: metaDesc,
        breadcrumb: {
          "@id": `${fullUrl}#breadcrumb`,
        },
        inLanguage: "en-US",
        potentialAction: [
          {
            "@type": "ReadAction",
            target: [fullUrl],
          },
        ],
      },
      {
        "@type": "ImageObject",
        inLanguage: "en-US",
        "@id": `${fullUrl}#primaryimage`,
        url: `${fullUrl}assets/images/cochise-welcome.png`,
        contentUrl: `${fullUrl}assets/images/cochise-welcome.png`,
        width: 940,
        height: 788,
      },
      {
        "@type": "BreadcrumbList",
        "@id": `${fullUrl}#breadcrumb`,
        itemListElement: [
          {
            "@type": "ListItem",
            position: 1,
            name: "Home",
          },
        ],
      },
      {
        "@type": "WebSite",
        "@id": `${fullUrl}#website`,
        url: fullUrl,
        name: siteName,
        description: "",
        publisher: {
          "@id": `${fullUrl}#organization`,
        },
        potentialAction: [
          {
            "@type": "SearchAction",
            target: {
              "@type": "EntryPoint",
              urlTemplate: `${fullUrl}?s={search_term_string}`,
            },
            "query-input": {
              "@type": "PropertyValueSpecification",
              valueRequired: true,
              valueName: "search_term_string",
            },
          },
        ],
        inLanguage: "en-US",
      },
      {
        "@type": "Organization",
        "@id": `${fullUrl}#organization`,
        name: siteName,
        url: fullUrl,
        logo: {
          "@type": "ImageObject",
          inLanguage: "en-US",
          "@id": `${fullUrl}#/schema/logo/image/`,
          url: `${fullUrl}assets/images/cochise-welcome.png`,
          contentUrl: `${fullUrl}assets/images/cochise-welcome.png`,
          width: 500,
          height: 195,
          caption: siteName,
        },
        image: {
          "@id": `${fullUrl}#/schema/logo/image/`,
        },
      },
    ],
  };

  return (
    <>
      <script type="application/ld+json" dangerouslySetInnerHTML={{ __html: JSON.stringify(jsonLd) }} />
      <HomeBgVideo />
      <Homepage />
      <BeforeFooterBlock />
    </>
  );
}
