import type { CollectionConfig } from "payload";
import { lexicalEditor } from "@payloadcms/richtext-lexical";
import formatSlug from "@/utils/payload/formatSlug";

export const Teams: CollectionConfig = {
  slug: "teams",
  fields: [
    {
      name: "name",
      type: "text",
      required: true,
    },
    {
      name: "slug",
      type: "text",
      hooks: {
        beforeValidate: [formatSlug("name")],
      },
    },
    {
      name: "role",
      type: "text",
      required: true,
    },
    {
      name: "img",
      label: "Image",
      type: "upload",
      relationTo: "media",
      required: true,
    },
    {
      name: "biography",
      type: "richText",
      editor: lexicalEditor({}),
    },
    {
      name: "meta",
      label: "Page Meta",
      type: "group",
      fields: [
        {
          name: "title",
          label: "Title",
          type: "text",
        },
        {
          name: "description",
          label: "Description",
          type: "textarea",
        },
        {
          name: "canonical_url",
          label: "Canonical Url",
          type: "text",
        },
      ],
    },
  ],
  admin: {
    hideAPIURL: true,
    useAsTitle: "name",
    group: "General",
  },
};
