import Link from "next/link";
import { FaArrowRight } from "react-icons/fa";

export interface BeforeFooterBlockProps {
  id?: string;
  title?: string;
  description?: string;
  buttonText?: string;
  showLinier?: boolean;
}

const placeholderTitle = "Begin your path to healing with Cochise Oncology";
const placeholderDescription =
  "Our dedicated team in Sierra Vista, AZ is here to support you with hope, strength, and courage. We offer personalized cancer care using innovative treatments in our state-of-the-art facility. Take the first step towards comprehensive, patient-focused treatment by scheduling a consultation. Let us listen to your needs, answer your questions, and create a tailored plan for your journey. Fill out our form to connect with our compassionate experts and discover how Cochise Oncology can stand with you in your fight against cancer.";
const placeholderButtonText = "Get Started";

export function BeforeFooterBlock({ title, description, buttonText, showLinier = true }: BeforeFooterBlockProps) {
  return (
    <section
      className="relative py-16 px-6 text-center text-white"
      style={{ background: "linear-gradient(to right, #64B3B4, #A8DCCA)" }}
    >
      {showLinier && (
        <div className="absolute top-0 left-0 w-full overflow-hidden leading-none rotate-180">
          <svg
            viewBox="0 0 1200 120"
            xmlns="http://www.w3.org/2000/svg"
            preserveAspectRatio="none"
            className="w-full h-[100px]"
          >
            <path
              d="M0,80 C150,110 350,20 600,80 C850,140 1050,40 1200,80 L1200,120 L0,120 Z"
              fill="white"
              opacity="0.8"
            ></path>
            <path
              d="M0,90 C150,130 350,50 600,90 C850,150 1050,60 1200,90 L1200,120 L0,120 Z"
              fill="white"
              opacity="0.5"
            ></path>
            <path
              d="M0,100 C150,150 350,80 600,100 C850,160 1050,90 1200,100 L1200,120 L0,120 Z"
              fill="white"
              opacity="0.3"
            ></path>
          </svg>
        </div>
      )}

      <div className="max-w-4xl mx-auto mt-12">
        <h4 className="text-4xl font-medium mb-3">{title ?? placeholderTitle}</h4>
        <span className="text-lg leading-relaxed mb-6">{description ?? placeholderDescription}</span>
        <div className="pt-5">
          <Link href="/contact" className="ext-btn-cta-md">
            {buttonText ?? placeholderButtonText} <FaArrowRight />
          </Link>
        </div>
      </div>
    </section>
  );
}
