import { fetchContact } from "@/services/payload/contact";
import { Suspense } from "react";
import { FaClock, FaFax, FaMapMarkerAlt } from "react-icons/fa";
import { GiRotaryPhone } from "react-icons/gi";

export default function ContactBlock() {
  return (
    <>
      <Suspense fallback={<ContactSkeleton />}>
        <ContactWithData />
      </Suspense>
    </>
  );
}

async function ContactWithData() {
  const contact = await fetchContact();

  return (
    <div className="container position-relative">
      <div className="row">
        <div className="col-lg-6">
          <div className="row mb-50">
            <div className="col-lg-10">
              <h2 className="section-caption-slick mb-xs-10">Contact Us</h2>
            </div>
          </div>
        </div>
      </div>
      <div className="row">
        <div className="col-md-6 mb-sm-10">
          {/* Contact Form */}
          <div className="row mb-60 mb-sm-50">
            {/* Contact Item */}
            <div className="col-sm-6 mb-xs-30 d-flex align-items-stretch">
              <div className="alt-features-item border-left mt-0 fadeScaleIn">
                <FaMapMarkerAlt className="text-4xl m-5" />
                <h4 className="alt-features-title">Location</h4>
                <div className="alt-features-descr clearlinks">
                  <div>
                    <a target="_blank" href={contact?.location?.href ?? "#"}>
                      {contact?.fullLocation ?? ""}
                    </a>
                  </div>
                </div>
              </div>
            </div>
            {/* End Contact Item */}
            {/* Contact Item */}
            <div className="col-sm-6 d-flex align-items-stretch">
              <div className="alt-features-item border-left mt-0 fadeScaleIn">
                <GiRotaryPhone className="text-4xl m-5" />
                <h4 className="alt-features-title">Phone</h4>
                <div className="alt-features-descr clearlinks">
                  <div>
                    <a href={`tel:${contact?.phone ?? "#"}`}>{contact?.phone ?? ""}</a>
                  </div>
                </div>
              </div>
            </div>
            {/* End Contact Item */}
          </div>
          <div className="row mb-60 mb-sm-50">
            {/* Contact Item */}
            <div className="col-sm-6 mb-xs-30 d-flex align-items-stretch">
              <div className="alt-features-item border-left mt-0 fadeScaleIn">
                <FaClock className="text-4xl m-5" />
                <h4 className="alt-features-title">Hours</h4>
                <div className="alt-features-descr clearlinks">
                  {Array.isArray(contact?.hours) &&
                    contact.hours.map((h) => (
                      <p key={h.id} className="text-wrap">
                        {h.hour ?? ""}
                      </p>
                    ))}
                </div>
              </div>
            </div>
            {/* End Contact Item */}
            {/* Contact Item */}
            <div className="col-sm-6 mb-xs-30 d-flex align-items-stretch">
              <div className="alt-features-item border-left mt-0 fadeScaleIn">
                <FaFax className="text-4xl m-5" />
                <h4 className="alt-features-title">Fax</h4>
                <div className="alt-features-descr clearlinks">
                  <div>
                    <a href={`tel:${contact?.fax ?? "#"}`}>{contact?.fax ?? ""}</a>
                  </div>
                </div>
              </div>
            </div>
            {/* End Contact Item */}
          </div>
          {/* End Contact Form */}
        </div>
        <div className="col-md-6 d-flex align-items-stretch">
          {/* Google Map */}
          <div className="map-boxed">
            <iframe
              src="https://www.google.com/maps/embed?pb=!1m14!1m8!1m3!1d108795.7060636289!2d-110.242613!3d31.555297!3m2!1i1024!2i768!4f13.1!3m3!1m2!1s0x86d7292e9b858975%3A0xc2519e5d827cd79c!2sCochise%20Oncology!5e0!3m2!1sen!2sus!4v1740412623968!5m2!1sen!2sus"
              width={600}
              height={450}
              style={{ border: 0 }}
              loading="lazy"
              referrerPolicy="no-referrer-when-downgrade"
            />
          </div>
          {/* End Google Map */}
        </div>
      </div>
    </div>
  );
}

function ContactSkeleton() {
  return (
    <div className="container position-relative animate-pulse">
      <div className="row">
        <div className="col-lg-6">
          <div className="row mb-50">
            <div className="col-lg-10">
              <h2 className="section-caption-slick mb-xs-10">Contact Us</h2>
            </div>
          </div>
        </div>
      </div>
      <div className="row">
        <div className="col-md-6 mb-sm-10">
          {/* Contact Form */}
          <div className="row mb-60 mb-sm-50">
            {/* Contact Item */}
            <div className="col-sm-6 mb-xs-30 d-flex align-items-stretch">
              <div className="flex-1 alt-features-item border-left mt-0">
                <FaMapMarkerAlt className="text-4xl m-5" />
                <h4 className="alt-features-title">Location</h4>
                <div className="h-3 bg-gray-300 rounded flex-1"></div>
              </div>
            </div>
            {/* End Contact Item */}
            {/* Contact Item */}
            <div className="col-sm-6 d-flex align-items-stretch">
              <div className="flex-1 alt-features-item border-left mt-0">
                <GiRotaryPhone className="text-4xl m-5" />
                <h4 className="alt-features-title">Phone</h4>
                <div className="h-3 bg-gray-300 rounded flex-1"></div>
              </div>
            </div>
            {/* End Contact Item */}
          </div>
          <div className="row mb-60 mb-sm-50">
            {/* Contact Item */}
            <div className="col-sm-6 mb-xs-30 d-flex align-items-stretch">
              <div className="flex-1 alt-features-item border-left mt-0">
                <FaClock className="text-4xl m-5" />
                <h4 className="alt-features-title">Hours</h4>
                <div className="h-3 bg-gray-300 rounded flex-1"></div>
              </div>
            </div>
            {/* End Contact Item */}
            {/* Contact Item */}
            <div className="col-sm-6 mb-xs-30 d-flex align-items-stretch">
              <div className="flex-1 alt-features-item border-left mt-0">
                <FaFax className="text-4xl m-5" />
                <h4 className="alt-features-title">Fax</h4>
                <div className="h-3 bg-gray-300 rounded flex-1"></div>
              </div>
            </div>
            {/* End Contact Item */}
          </div>
          {/* End Contact Form */}
        </div>
        <div className="col-md-6 d-flex align-items-stretch">
          {/* Google Map */}
          <div className="h-80 bg-gray-300 rounded flex-1"></div>
          {/* End Google Map */}
        </div>
      </div>
    </div>
  );
}
