import type { ElementType } from "react";

import Link from "next/link";
import React from "react";
import { CgSpinner } from "react-icons/cg";

export type Props = {
  appearance?: "default" | "primary" | "secondary";
  className?: string;
  el?: "a" | "button" | "link";
  form?: string;
  href?: string;
  label?: string;
  newTab?: boolean | null;
  onClick?: () => void;
  isLoading?: boolean;
};

export const Button: React.FC<Props> = ({
  className: classNameFromProps,
  el = "button",
  form,
  href,
  label,
  newTab,
  isLoading,
}) => {
  const newTabProps = newTab ? { rel: "noopener noreferrer", target: "_blank" } : {};
  const Element: ElementType = el;
  const className = [classNameFromProps].filter(Boolean).join(" ");

  const elementProps = {
    ...newTabProps,
    className,
    form,
    href,
  };

  const content = (
    <div className="btn btn-mod btn-color btn-large btn-full btn-circle btn-hover-anim">
      <span className="flex flex-row">
        {label} {isLoading && <CgSpinner color="var(--ext-color-primary-1)" className="animate-spin ml-2" size={24} />}
      </span>
    </div>
  );

  return (
    <Element {...elementProps} {...{ disabled: isLoading }}>
      <React.Fragment>
        {(el === "link" || el === "a") && (
          <Link {...newTabProps} href={href || ""}>
            {content}
          </Link>
        )}
        {el === "button" && <>{content}</>}
      </React.Fragment>
    </Element>
  );
};
