"use client";

import { CardStarRating, CardStarRatingProps, CardStarRatingSkeleton } from "@/components/Ratings/CardStarRating";
import StarRating from "@/components/Ratings/StarRating";
import Image from "next/image";
import { Navigation } from "swiper/modules";
import { Swiper, SwiperSlide } from "swiper/react";

export interface GoogleReviewProps {
  data: {
    ratingValue: number;
    totalRating: number;
    data: CardStarRatingProps["data"][];
  };
}

export function GoogleReviews({ data }: GoogleReviewProps) {
  return (
    <section className="bg-scroll relative">
      {/* <div className="decoration-14" />
      <div className="decoration-15" /> */}
      <div className="decoration-16 opacity-035 d-none d-md-block">
        <Image src="/assets/images/demo-slick/decoration-2.svg" alt="Image Description" width={128} height={228} />
      </div>
      <div className="decoration-17 opacity-035 d-none d-md-block">
        <Image src="/assets/images/demo-slick/decoration-2.svg" alt="Image Description" width={128} height={228} />
      </div>

      <div className="container px-6">
        <h2 className="text-3xl font-bold text-center">Reviews</h2>

        <div className="flex justify-center items-center space-x-2">
          <h2 className="text-xl text-center font-bol mt-[15px]">{data.ratingValue}</h2>
          <div className="mt-1">
            <StarRating size={30} value={data.ratingValue} />
          </div>
          <div className="font-medium">Over {data.totalRating} Reviews</div>
        </div>

        <div className="mt-20 relative">
          <Swiper
            loop
            spaceBetween={0}
            slidesPerView={3}
            breakpoints={{
              900: {
                slidesPerView: 3,
              },
              500: {
                slidesPerView: 2, // When window width is <= 480px
              },
              0: {
                slidesPerView: 1,
              },
            }}
            modules={[Navigation]}
            navigation={{
              prevEl: ".snbp1",
              nextEl: ".snbn1",
            }}
            watchSlidesProgress
            resizeObserver
            className="team-carousel owl-carousel owl-theme overflow-hidden position-static"
            style={{
              opacity: 1,
              display: "block",
            }}
          >
            {/* Group item */}
            {data.data.map((rev, index) => (
              <SwiperSlide className="owl-item py-2 mt-5" key={index}>
                <div>
                  <CardStarRating data={rev} />
                </div>
              </SwiperSlide>
            ))}
            <div className="owl-controls clickable absolute top-6 w-full">
              <div className="owl-buttons">
                <div className="owl-prev snbp1 left" role="button" tabIndex={0}>
                  <span className="visually-hidden">Previous Slide</span>
                  <i className="mi-arrow-left" aria-hidden="true"></i>
                </div>
                <div className="owl-next snbn1" role="button" tabIndex={0}>
                  <span className="visually-hidden">Next Slide</span>
                  <i className="mi-arrow-right" aria-hidden="true"></i>
                </div>
              </div>
            </div>
            {/* End Group item */}
          </Swiper>
        </div>
      </div>
    </section>
  );
}

export function GoogleReviewsSkeleton() {
  return (
    <section className="bg-scroll relative">
      <div className="decoration-14" />
      <div className="decoration-15" />
      <div className="decoration-16 opacity-035 d-none d-md-block">
        <Image src="/assets/images/demo-slick/decoration-2.svg" alt="Image Description" width={128} height={228} />
      </div>
      <div className="decoration-17 opacity-035 d-none d-md-block">
        <Image src="/assets/images/demo-slick/decoration-2.svg" alt="Image Description" width={128} height={228} />
      </div>

      <div className="container px-6">
        <h2 className="text-3xl font-bold text-center">Reviews</h2>
        <GoogleReviewsHeaderSkeleton />

        <GoogleReviewsContentSkeleton />
      </div>
    </section>
  );
}

function GoogleReviewsHeaderSkeleton() {
  return (
    <div className="animate-pulse flex flex-1 justify-center">
      <div className="h-5 bg-gray-300 rounded w-1/3 mb-2"></div>
    </div>
  );
}

function GoogleReviewsContentSkeleton() {
  return (
    <div className="mt-20 relative">
      <Swiper
        loop
        spaceBetween={0}
        slidesPerView={3}
        breakpoints={{
          900: {
            slidesPerView: 3,
          },
          500: {
            slidesPerView: 2, // When window width is <= 480px
          },
          0: {
            slidesPerView: 1,
          },
        }}
        modules={[Navigation]}
        navigation={{
          prevEl: ".snbp1",
          nextEl: ".snbn1",
        }}
        watchSlidesProgress
        resizeObserver
        className="team-carousel owl-carousel owl-theme overflow-hidden position-static"
        style={{
          opacity: 1,
          display: "block",
        }}
      >
        {/* Group item */}
        <SwiperSlide className="owl-item py-2 mt-5">
          <CardStarRatingSkeleton />
        </SwiperSlide>
        <SwiperSlide className="owl-item py-2 mt-5">
          <CardStarRatingSkeleton />
        </SwiperSlide>
        <SwiperSlide className="owl-item py-2 mt-5">
          <CardStarRatingSkeleton />
        </SwiperSlide>
        <SwiperSlide className="owl-item py-2 mt-5">
          <CardStarRatingSkeleton />
        </SwiperSlide>

        <div className="owl-controls clickable absolute top-6 w-full">
          <div className="owl-buttons">
            <div className="owl-prev snbp1 left" role="button" tabIndex={0}>
              <span className="visually-hidden">Previous Slide</span>
              <i className="mi-arrow-left" aria-hidden="true"></i>
            </div>
            <div className="owl-next snbn1" role="button" tabIndex={0}>
              <span className="visually-hidden">Next Slide</span>
              <i className="mi-arrow-right" aria-hidden="true"></i>
            </div>
          </div>
        </div>
        {/* End Group item */}
      </Swiper>
    </div>
  );
}
