"use client";

import Image from "next/image";
import { Navigation } from "swiper/modules";
import { Swiper, SwiperSlide } from "swiper/react";

interface ImageSliderBlockProps {
  images: { id: string; image: { url: string; alt: string } }[];
}

export function ImageSliderBlock({ images }: ImageSliderBlockProps) {
  return (
    <div className="container px-6 py-4">
      <div className="mt-20 relative">
        <Swiper
          loop
          spaceBetween={0}
          slidesPerView={3}
          breakpoints={{
            900: {
              slidesPerView: 3,
            },
            500: {
              slidesPerView: 2, // When window width is <= 480px
            },
            0: {
              slidesPerView: 1,
            },
          }}
          modules={[Navigation]}
          navigation={{
            prevEl: ".snbp1",
            nextEl: ".snbn1",
          }}
          watchSlidesProgress
          resizeObserver
          className="team-carousel owl-carousel owl-theme overflow-hidden position-static"
          style={{
            opacity: 1,
            display: "block",
          }}
        >
          {/* Group item */}
          {images.map((item, index: number) => (
            <SwiperSlide className="owl-item py-2 mt-5" key={index}>
              <div className="w-full h-[250px]">
                <Image
                  src={item?.image?.url ?? ""}
                  width={0}
                  height={0}
                  sizes="100vw"
                  className="w-full h-auto rounded-md"
                  alt={item?.image?.alt ?? ""}
                />
              </div>
            </SwiperSlide>
          ))}
          <div className="owl-controls clickable">
            <div className="owl-buttons">
              <div className="owl-prev snbp1 lef" role="button" tabIndex={0}>
                <span className="visually-hidden">Previous Slide</span>
                <i className="mi-arrow-left" aria-hidden="true"></i>
              </div>
              <div className="owl-next snbn1" role="button" tabIndex={0}>
                <span className="visually-hidden">Next Slide</span>
                <i className="mi-arrow-right" aria-hidden="true"></i>
              </div>
            </div>
          </div>
          {/* End Group item */}
        </Swiper>
      </div>
    </div>
  );
}
