import React, { Fragment, Suspense } from "react";

import type { Page } from "@/payload-types";
import { ContentBlock } from "./Content";
import { BeforeFooterBlock } from "./BeforeFooter";
import { OurTeamBlock } from "./OurTeam";
import { HorizontalImageContentBlock } from "./HorizontalImageContent";
import { ImageSliderBlock } from "./ImageSlider";
import { BoxMenuGridBlock } from "./BoxMenuGrid";
import { GoogleReviewsBlock } from "./GoogleReviews";
import { GoogleReviewsSkeleton } from "./GoogleReviews/GoogleReviews";
import ContactBlock from "./Contact";
import { FormBlock } from "./Form";

const blockComponents = {
  contentBlock: ContentBlock,
  beforeFooterBlock: BeforeFooterBlock,
  ourTeamBlock: OurTeamBlock,
  horizontalImageContentBlock: HorizontalImageContentBlock,
  imageSliderBlock: ImageSliderBlock,
  boxMenuGridBlock: BoxMenuGridBlock,
  googleReviewBlock: GoogleReviewsBlock,
  contactBlock: ContactBlock,
  formBlock: FormBlock,
};

export const RenderBlocks: React.FC<{
  blocks: Page["layout"];
}> = (props) => {
  const { blocks } = props;

  const hasBlocks = blocks && Array.isArray(blocks) && blocks.length > 0;

  if (hasBlocks) {
    return (
      <Fragment>
        {blocks.map((block, index) => {
          const { blockType } = block;

          if (blockType && blockType in blockComponents) {
            const Block = blockComponents[blockType];
            if (!Block) return null;

            if (blockType === "googleReviewBlock") {
              return (
                <div className="my-10" key={index}>
                  <Suspense fallback={<GoogleReviewsSkeleton />}>
                    <GoogleReviewsBlock />
                  </Suspense>
                </div>
              );
            } else if (blockType === "formBlock") {
              return (
                <div className="my-10" key={index}>
                  <FormBlock
                    id={block.id}
                    enableIntro={block.enableIntro}
                    introContent={block.introContent}
                    form={block.form}
                  />
                </div>
              );
            } else if (blockType === "beforeFooterBlock") {
              return (
                <div className="mt-10" key={index}>
                  {/* @ts-ignore */}
                  <BeforeFooterBlock {...block} />
                </div>
              );
            } else {
              return (
                <div className="my-10" key={index}>
                  {/* @ts-ignore */}
                  <Block {...block} disableInnerContainer />
                </div>
              );
            }
          }
          return null;
        })}
      </Fragment>
    );
  }

  return null;
};
