import Image from "next/image";

export interface BlogCardItemProps {
  data: {
    slug: string | null | undefined;
    title: string;
    img?: {
      url: string;
      alt: string;
    };
    contentPreview: string;
    author?: {
      name: string;
      img: string;
    };
    date: string;
  };
}

export function BlogCardItem({ data }: BlogCardItemProps) {
  return (
    <div className="post-prev-3 col-12 col-md-6 col-lg-4 col-xl-4 mt-50">
      <div className="post-prev-3-container flex flex-col shadow-md hover:scale-[1.02]">
        <div className="relative w-full h-[200px]">
          <a href={`/${data.slug}/`}>
            <Image src={data?.img?.url ?? ""} alt={data?.img?.alt ?? ""} fill className="object-cover" />
          </a>
        </div>
        <div className="px-4 py-3 flex flex-col flex-1 justify-between">
          <h2 className="text-lg text-center">
            <a href={`/${data.slug}/`}>{data.title}</a>
          </h2>
          <div className="flex justify-center mt-2">
            <a href={`/${data.slug}/`} className="ext-btn-shadow-primary8">
              Continue Reading
            </a>
          </div>
        </div>
      </div>
    </div>
  );
}

export function BlogCardItemSkeleton() {
  return (
    <div className="post-prev-3 col-12 col-md-6 col-lg-4 col-xl-4 mt-50 animate-pulse">
      <div className="post-prev-3-container flex flex-col">
        <div className="h-48 w-full bg-gray-300"></div>
        <div className="px-4 py-3">
          <div className="space-y-2 flex flex-col items-center">
            <div className="h-4 bg-gray-300 rounded w-full"></div>
            <div className="h-4 bg-gray-300 rounded w-full"></div>
            <div className="h-4 bg-gray-300 rounded w-1/2"></div>
          </div>
        </div>
      </div>
    </div>
  );
}
