import Pagination from "@/components/Pagination";
import { fetchBlog } from "@/services/payload/blog";
import { BlogCardItem } from "./BlogCardItem";
import { sanitizeBlogContentIntoStringPreview } from "@/utils/sanitize";

export type BlogsProps = {
  page: number;
  search?: string;
} & (
  | {
      preset?: "blogs";
    }
  | {
      preset?: "categories";
      categoryId: number;
    }
  | {
      preset?: "tags";
      tagId: number;
    }
);

export default async function Blogs({ page, search, ...params }: BlogsProps) {
  const fetchBlogParams: Parameters<typeof fetchBlog>[0] = {
    page,
    search,
  };

  if (params.preset === "categories") {
    fetchBlogParams.categoryId = params.categoryId;
  }
  if (params.preset === "tags") {
    fetchBlogParams.tagId = params.tagId;
  }

  const data = await fetchBlog(fetchBlogParams);

  if (!data?.totalDocs) return <></>;

  return (
    <div className="container position-relative">
      {/* Blog Posts Grid */}
      <div className="row">
        {/* Post Item */}
        {data.formattedData.map((blog, i) => (
          <BlogCardItem
            key={i}
            data={{
              slug: blog.slug,
              title: blog.title,
              contentPreview: sanitizeBlogContentIntoStringPreview(blog.content),
              date: blog.createdAtFormatted,
              img: blog.imgFormatted,
            }}
          />
        ))}
        {/* End Post Item */}
      </div>
      {/* End Blog Posts Grid */}
      {/* Pagination */}
      {data.totalPages > 1 && (
        <div className="mt-20">
          <Pagination
            page={data.page ?? 1}
            hasNextPage={data.hasNextPage}
            hasPreviousPage={data.hasPrevPage}
            totalPages={data.totalPages}
            usePathParams={params.preset === "blogs" ? false : true}
          />
        </div>
      )}
      {/* End Pagination */}
    </div>
  );
}
