import React from "react";
import Image from "next/image";
import Link from "next/link";
import { fetchBlogSuggestion } from "@/services/payload/blog";
import { sanitizeBlogContentIntoStringPreview } from "@/utils/sanitize";

export default async function BlogsSuggestion() {
  const data = await fetchBlogSuggestion();

  if (!data?.totalDocs) return <></>;

  return (
    <>
      {/* End Background Shape */}
      <div className="container position-relative">
        <div className="row mb-60 mb-sm-40">
          <div className="col-lg-8 offset-lg-2 text-center mb-md-30">
            <h2 className="section-caption-slick mb-30 mb-sm-20">Our Blog</h2>
            <h3 className="section-title-large mb-30">Knowledge and Support for Your Cancer Journey</h3>
            <p className="mb-0">
              Cancer treatment involves a team of specialists providing personalized, comprehensive care. Staying
              informed and engaged empowers you to choose the best approach. Remember, you’re not alone in this journey.
            </p>
          </div>
        </div>
        {/* Blog Posts Grid */}
        <div className="row mt-n30">
          {/* Post Item */}
          {data?.formattedData?.map((elm, i) => (
            <div key={i} className="post-prev-3 col-12 col-lg-10 offset-lg-1 col-xl-6 offset-xl-0 mt-30">
              <div className="post-prev-3-container d-block d-sm-flex">
                <div className="post-prev-3-img">
                  <Link href={`/${elm.slug ?? ""}`}>
                    <Image
                      src={elm?.imgFormatted?.url ?? ""}
                      width={400}
                      height={200}
                      alt="Add Image Description"
                      className="wow scaleOutIn"
                    />
                  </Link>
                </div>
                <div className="post-prev-3-intro">
                  <h4 className="post-prev-3-title">
                    <Link href={`/${elm.slug ?? ""}`}>{elm.title}</Link>
                  </h4>
                  <div className="post-prev-3-text">{sanitizeBlogContentIntoStringPreview(elm.content)}</div>
                  <div className="post-prev-3-info clearfix">
                    <div className="float-end">
                      <a href="#">{elm.createdAtFormatted}</a>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          ))}
          {/* End Post Item */}
        </div>
        {/* End Blog Posts Grid */}
      </div>
    </>
  );
}
