import Image from "next/image";
import { FaClock, FaFacebookF, FaFax, FaLinkedinIn, FaMapMarkerAlt } from "react-icons/fa";
import { GiRotaryPhone } from "react-icons/gi";
import ScrollToTop from "./ScrollToTop";
import { fetchContact } from "@/services/payload/contact";
import { Suspense } from "react";

export default async function Footer() {
  return (
    <>
      <Suspense fallback={<FooterSkeleton />}>
        <FooterWithData />
      </Suspense>
    </>
  );
}

async function FooterWithData() {
  const contact = await fetchContact();

  return (
    <div
      className="relative text-white py-10"
      style={{
        backgroundColor: "transparent",
        backgroundImage: "linear-gradient(172deg, #798D90 0%, #C48853 100%)",
      }}
    >
      <div className="container mx-auto flex flex-wrap justify-around items-start px-6">
        <div className="w-full md:w-1/4 mb-6 md:mb-0 flex flex-col items-start">
          <Image src="/assets/images/demo-slick/logo-dark.webp" alt="Cochise Oncology Logo" width={363} height={138} />
          <p className="mt-4 mb-2">© {new Date().getFullYear()} All Rights Reserved</p>
          <a href="/privacy-policy" className="text text-extColorPrimary8 font-semibold">
            Privacy Policy
          </a>
        </div>

        <div className="w-full md:w-1/3 mb-6 md:mb-0">
          <h3 className="text-lg font-semibold mb-4">Contact Us</h3>
          <ul className="space-y-4 border-gray-400 pl-0">
            <li className="flex items-center space-x-4 border-b-[0.8px] border-[#b69a89] pb-2">
              <FaMapMarkerAlt className="text-2xl text-white-300" />
              <div className="leading-tight">
                <a
                  href={contact?.location?.href ?? ""}
                  target="_blank"
                  rel="noopener noreferrer"
                  className="text-lg text-white"
                >
                  {contact?.location?.street ?? ""}
                </a>
                <br />
                <span className="text-sm text-white-300">{contact?.fullLocation ?? ""}</span>
              </div>
            </li>
            <li className="flex items-center space-x-4 border-b-[0.8px] border-[#b69a89] pb-2">
              <GiRotaryPhone className="text-2xl text-white-300" />
              <a
                href={`tel:${contact?.phone ?? ""}`}
                target="_blank"
                rel="noopener noreferrer"
                className="text-lg text-white text-[18px]"
              >
                {contact?.phone ?? ""}
              </a>
            </li>
            <li className="flex items-center space-x-4 border-b-[0.8px] border-[#b69a89] pb-2">
              <FaFax className="text-2xl text-white-300" />
              <a
                href={`tel:${contact?.fax ?? ""}`}
                target="_blank"
                rel="noopener noreferrer"
                className="text-lg text-white text-[18px]"
              >
                Fax: {contact?.fax ?? ""}
              </a>
            </li>
            <li className="flex items-center space-x-4 border-b-[0.8px] border-[#b69a89] pb-2">
              <FaFacebookF className="text-2xl text-white-300" />
              <a
                href={contact?.facebook ?? ""}
                target="_blank"
                rel="noopener noreferrer"
                className="text-lg text-white text-[18px]"
              >
                Facebook
              </a>
            </li>
            <li className="flex items-center space-x-4">
              <FaLinkedinIn className="text-2xl text-white-300" />
              <a
                href={contact?.linkedin ?? ""}
                target="_blank"
                rel="noopener noreferrer"
                className="text-lg text-white text-[18px]"
              >
                Linkedin
              </a>
            </li>
          </ul>
        </div>

        <div className="w-full md:w-1/4">
          <h3 className="text-lg font-semibold mb-4">Business Hours</h3>
          {contact?.hours?.map?.((hour) => (
            <div key={hour.id} className="flex items-center space-x-2">
              <FaClock className="text-xl" />
              <span className="text-base font-medium">{hour?.hour ?? ""}</span>
            </div>
          )) ?? []}
        </div>
      </div>

      <div className="text-center mt-6">
        <ScrollToTop />
      </div>
    </div>
  );
}

function FooterSkeleton() {
  return (
    <div
      className="relative text-white py-10"
      style={{
        backgroundColor: "transparent",
        backgroundImage: "linear-gradient(172deg, #798D90 0%, #C48853 100%)",
      }}
    >
      <div className="container mx-auto flex flex-wrap justify-around items-start px-6">
        <div className="w-full md:w-1/4 mb-6 md:mb-0 flex flex-col items-start">
          <Image src="/assets/images/demo-slick/logo-dark.webp" alt="Cochise Oncology Logo" width={363} height={138} />
          <p className="text-sm mt-3">© {new Date().getFullYear()} All Rights Reserved</p>
        </div>

        <div className="w-full md:w-1/3 mb-6 md:mb-0 animate-pulse">
          <h3 className="text-lg font-semibold mb-4">Contact Us</h3>
          <ul className="space-y-4 border-gray-400 pl-0">
            <li className="flex items-center space-x-4 border-b-[0.8px] border-[#b69a89] pb-2">
              <FaMapMarkerAlt className="text-2xl text-gray-300" />
              <div className="h-2 bg-gray-300 rounded flex-1"></div>
              <div className="h-2 bg-gray-300 rounded flex-1"></div>
            </li>
            <li className="flex items-center space-x-4 border-b-[0.8px] border-[#b69a89] pb-2">
              <GiRotaryPhone className="text-2xl text-gray-300" />
              <div className="h-2 bg-gray-300 rounded flex-1"></div>
              <div className="h-2 bg-gray-300 rounded flex-1"></div>
            </li>
            <li className="flex items-center space-x-4 border-b-[0.8px] border-[#b69a89] pb-2">
              <FaFax className="text-2xl text-gray-300" />
              <div className="h-2 bg-gray-300 rounded flex-1"></div>
              <div className="h-2 bg-gray-300 rounded flex-1"></div>
            </li>
            <li className="flex items-center space-x-4 border-b-[0.8px] border-[#b69a89]">
              <FaFacebookF className="text-2xl text-gray-300" />
              <div className="h-2 bg-gray-300 rounded flex-1"></div>
              <div className="h-2 bg-gray-300 rounded flex-1"></div>
            </li>
            <li className="flex items-center space-x-4">
              <FaLinkedinIn className="text-2xl text-gray-300" />
              <div className="h-2 bg-gray-300 rounded flex-1"></div>
              <div className="h-2 bg-gray-300 rounded flex-1"></div>
            </li>
          </ul>
        </div>

        <div className="w-full md:w-1/4 animate-pulse">
          <h3 className="text-lg font-semibold mb-4">Business Hours</h3>
          <div className="flex items-center space-x-2">
            <FaClock className="text-xl" />
            <div className="h-2 bg-white-300 rounded flex-1"></div>
            <div className="h-2 bg-white-300 rounded flex-1"></div>
          </div>
        </div>
      </div>
    </div>
  );
}
