"use client";

import HeaderNav from "@/components/HeaderNav";
import { navMenuData } from "@/data/menu";
import { toggleMobileMenu } from "@/utils/toggleMobileMenu";
import Image from "next/image";
import Link from "next/link";
import { FaFacebook, FaLinkedin } from "react-icons/fa";

const shareIcons: Record<string, any> = {
  phone: {
    link: "tel:+15208036644",
    dom: (
      <span className="social-nav flex text-2xl text-white space-x-3 lg:space-x-1">
        <Image src="/assets/icons/phone.png" alt="Phone" width={30} height={25} />
        <b className="text-[17px] hover:!text-extColorPrimary3 transition-all duration-300">(520) 803-6644</b>
      </span>
    ),
  },
  facebook: {
    link: "https://www.facebook.com/p/Cochise-Oncology-61556262839823",
    dom: (
      <span className="social-nav flex text-2xl text-white space-x-3 lg:space-x-1">
        <FaFacebook size={25} className="hover:!text-extColorPrimary3 transition-all duration-300" />
        <b className="text-[17px] lg:hidden">Facebook</b>
      </span>
    ),
  },
  linkedin: {
    link: "https://linkedin.com/company/cochise-oncology",
    dom: (
      <span className="social-nav flex text-2xl text-white space-x-3 lg:space-x-1">
        <FaLinkedin size={25} className="hover:!text-extColorPrimary3" />
        <b className="text-[17px] lg:hidden">Linkedin</b>
      </span>
    ),
  },
};

export default function Header({ links }: { links: typeof navMenuData }) {
  return (
    <nav className="main-nav dark stick-fixed wow-menubar wch-unset relative">
      <div className="main-nav-sub full-wrapper">
        <div className="nav-logo-wrap local-scroll lg:hidden">
          <Link href={`/`} className="logo">
            <Image
              src="/assets/images/demo-slick/logo-dark.webp"
              alt="Company Logo"
              width={250}
              height={150}
              className="dark-mode-logo"
            />
          </Link>
        </div>
        {/* Mobile Menu Button */}
        <div onClick={toggleMobileMenu} className="mobile-nav" role="button" tabIndex={0}>
          <i className="mobile-nav-icon" />
          <span className="visually-hidden">Menu</span>
        </div>
        {/* Main Menu */}
        <div className="inner-nav desktop-nav">
          <ul className="clearlist local-scroll">
            <li className="!hidden lg:!block">
              <Link href={`/`} className="logo">
                <Image
                  src="/assets/images/demo-slick/logo-dark.webp"
                  alt="Company Logo"
                  width={204}
                  height={104}
                  className="dark-mode-logo"
                />
              </Link>
            </li>
            <HeaderNav links={links} />
            <li>
              <div className="flex flex-col items-center h-full w-full content-center justify-center gap-2">
                <div className="flex justify-center">
                  <a href="/contact" className="ext-btn-cta">
                    REQUEST CONSULTATION
                  </a>
                </div>
                <div className="flex justify-between w-full flex-col lg:flex-row">
                  {Object.keys(shareIcons).map((k, idx) => {
                    return (
                      <div key={idx} className="!p-0 !m-0">
                        <a className="cursor-pointer text-white" href={shareIcons[k].link} target="_blank">
                          {shareIcons[k].dom}
                        </a>
                      </div>
                    );
                  })}
                </div>
              </div>
            </li>
          </ul>
        </div>

        {/* End Main Menu */}
      </div>
    </nav>
  );
}
