"use client";

import { navMenuData } from "@/data/menu";
import addScrollspy from "@/utils/addScroll";
import { init_classic_menu_resize } from "@/utils/menuToggle";
import { scrollToElement } from "@/utils/scrollToElement";
import { toggleMobileMenu } from "@/utils/toggleMobileMenu";
import Link from "next/link";
import { Fragment, useEffect, useRef, useState } from "react";
import { FaCaretDown, FaCaretRight } from "react-icons/fa";

export default function HeaderNav({ links, animateY = false }: { links: typeof navMenuData; animateY?: boolean }) {
  const [hoveredNavItem, setHoveredNavItem] = useState("");
  const [hoveredSubNavItem, setHoveredSubNavItem] = useState("");
  const [isDropdownOpen, setIsDropdownOpen] = useState([""]);
  const [isSubDropdownOpen, setIsSubDropdownOpen] = useState("");
  const dropdownRef = useRef(null);

  const toggleDropdown = (section: string[]) => {
    if (section == isDropdownOpen) {
      setIsDropdownOpen([""]);
    }
    setIsDropdownOpen(section);
  };

  useEffect(() => {
    setTimeout(() => {
      scrollToElement();
    }, 1000);
    init_classic_menu_resize();
    window.addEventListener("scroll", addScrollspy as any);

    window.addEventListener("resize", init_classic_menu_resize);

    return () => {
      window.removeEventListener("scroll", addScrollspy as any);
      window.removeEventListener("resize", init_classic_menu_resize);
    };
  }, []);

  return (
    <>
      {links.map((link, index) => (
        <Fragment key={index}>
          <li>
            {!Array.isArray(link?.child) && (
              <Link
                prefetch={false}
                href={link.href}
                className="!text-white hover:!text-extColorPrimary3 !text-[20px] !transition-all !duration-500"
              >
                {animateY ? (
                  <span className="btn-animate-y">
                    <span className="btn-animate-y-1">{link.text}</span>
                    <span className="btn-animate-y-2" aria-hidden="true">
                      {link.text}
                    </span>
                  </span>
                ) : (
                  link.text
                )}
              </Link>
            )}

            {Array.isArray(link?.child) && (
              <div onMouseOver={() => setHoveredNavItem(`${index}`)} onMouseLeave={() => setHoveredNavItem("")}>
                <Link
                  prefetch={false}
                  href={link?.href ?? "#"}
                  className="mn-has-sub !flex justify-between items-center !text-white hover:!text-extColorPrimary3 !text-[20px] !transition-all !duration-500"
                  onClick={() => toggleDropdown([link.text])}
                >
                  {link.text} <FaCaretDown className="ml-2" />
                </Link>
                <ul
                  className={`font-fontSecondary mn-sub to-right mt-2 ${isDropdownOpen.includes(link.text) && "open"} !bg-extColorPrimary8 ${hoveredNavItem.includes(`${index}`) ? "lg:visible lg:opacity-100 lg:z-10" : "lg:invisible lg:opacity-0"} !transition-all !duration-300 lg:shadow-nav`}
                  ref={dropdownRef}
                >
                  {link.child.map((subLink: any, subLinkIdx: number) => (
                    <li
                      key={subLinkIdx}
                      onMouseOver={() => setHoveredSubNavItem(`${index}-${subLinkIdx}`)}
                      onMouseLeave={() => setHoveredSubNavItem("")}
                    >
                      {!Array.isArray(subLink?.child) && (
                        <Link
                          prefetch={false}
                          href={subLink?.href}
                          onClick={() => toggleMobileMenu()}
                          className="!text-[14px] !text-white hover:!bg-extColorPrimary5 hover:!text-extColorPrimary3 !transition-all !duration-500"
                        >
                          {subLink?.text}
                        </Link>
                      )}
                      {Array.isArray(subLink?.child) && (
                        <>
                          <Link
                            prefetch={false}
                            href={subLink?.href ?? "#"}
                            className="mn-has-sub !flex !justify-between !items-center !text-white hover:!bg-extColorPrimary5 hover:!text-extColorPrimary3 transition-all duration-500"
                            onClick={() => setIsSubDropdownOpen(`${index}-${subLinkIdx}`)}
                          >
                            <span className="!text-[14px]">{subLink.text}</span>
                            <FaCaretRight className="ml-2" />
                          </Link>

                          <ul
                            className={`mn-sub to-right ${isSubDropdownOpen.includes(`${index}-${subLinkIdx}`) && "open"} ${hoveredSubNavItem.includes(`${index}-${subLinkIdx}`) ? "lg:visible lg:opacity-100 lg:z-10" : "lg:invisible lg:opacity-0"} !bg-extColorPrimary8 !transition-all !duration-300 lg:shadow-nav`}
                          >
                            {subLink.child.map((subLink2: any, subLinkIdx2: number) => (
                              <li key={subLinkIdx2}>
                                <Link
                                  prefetch={false}
                                  href={subLink2?.href}
                                  className="!text-[14px] !items-center !text-white hover:!bg-extColorPrimary5 hover:!text-extColorPrimary3 transition-all duration-500"
                                  onClick={() => toggleMobileMenu()}
                                >
                                  {subLink2?.text}
                                </Link>
                              </li>
                            ))}
                          </ul>
                        </>
                      )}
                    </li>
                  ))}
                </ul>
              </div>
            )}
          </li>
          {index != links.length - 1 && (
            <div
              className="text-white bg-white h-[1px] lg:h-[25px] mx-2 opacity-[0.3]"
              style={{ border: "1px solid white" }}
            />
          )}
        </Fragment>
      ))}
    </>
  );
}
