import Image from "next/image";
import { FaFacebook, FaLinkedin, FaTwitter } from "react-icons/fa";

export interface HeroOtherProps {
  title?: string;
  img?: string;
  createdAt?: string;
  shareUrl?: Record<string, string>;
}

const shareIcons: Record<string, any> = {
  facebook: <FaFacebook className="text-2xl text-gray-300" />,
  linkedin: <FaLinkedin className="text-2xl text-gray-300" />,
  twitter: <FaTwitter className="text-2xl text-gray-300" />,
};

export default function HeroOther({ title, img, createdAt, shareUrl }: HeroOtherProps) {
  return (
    <section className="page-section bg-dark-1 bg-gradient-gray-dark-1 light-content bg-scroll overflow-hidden !py-20 !pt-52 md:!pb-28 relative min-h-[48vh]">
      {/* <!-- Background Shape --> */}
      <div className="bg-shape-1 w-full h-full opacity-50 bg-contain">
        <Image src={img || "/assets/images/hero-default.webp"} alt="" fill className="object-cover" />
      </div>
      {/* <!-- End Background Shape --> */}

      <div className="container position-relative text-center">
        <div className="row">
          <div className="col-md-10 offset-md-1 col-lg-8 offset-lg-2">
            <h1 className="text-5xl !font-medium mb-10 leading-[1.5]">{title ?? ""}</h1>
            {!!createdAt && (
              <div className="blog-item-data mb-0 wow fadeIn" data-wow-delay="0.2s">
                <div className="flex justify-center items-center">
                  <i className="mi-clock mr-2" />
                  <a href="#">{createdAt}</a>
                </div>
              </div>
            )}

            {!!shareUrl && (
              <div className="flex justify-center space-x-5 mt-8 wow fadeIn">
                {Object.keys(shareUrl).map((k, idx) => {
                  return (
                    <a key={idx} className="cursor-pointer" href={shareUrl[k]} target="_blank">
                      {shareIcons[k]}
                    </a>
                  );
                })}
              </div>
            )}
          </div>
        </div>
      </div>

      <svg className="absolute bottom-[-10px] left-0 w-full" viewBox="0 0 1440 50" xmlns="http://www.w3.org/2000/svg">
        <path fill="white" d="M0,0 C480,40 960,40 1440,0 L1440,50 L0,50 Z"></path>
      </svg>
    </section>
  );
}
