import Image from "next/image";
import Link from "next/link";
import About from "./About";
import Testimonials from "./Testimonials";
import ContactBlock from "./Blocks/Contact";

export default function homepage({ dark = false }) {
  return (
    <>
      <section className="w-full py-5 bg-gradient-to-b from-white to-extColorPrimary7 relative">
        <div className="bg-scroll">
          <div className="decoration-16 opacity-035 d-none d-md-block">
            <Image src="/assets/images/demo-slick/decoration-2.svg" alt="Image Description" width={128} height={228} />
          </div>
          <div className="decoration-17 opacity-035 d-none d-md-block">
            <Image src="/assets/images/demo-slick/decoration-2.svg" alt="Image Description" width={128} height={228} />
          </div>
        </div>
        <div className="relative">
          <div className="w-full mt-[-100px] md:mt-[-150px] lg:mt-[-100px] 2xl:mt-[-200px] mb-[50px] z-[99] flex justify-center">
            <div className="bg-white h-full flex flex-col lg:flex-row flex-wrap justify-center p-4 lg:p-8 gap-3 rounded-xl shadow-xl">
              <Image
                className="rounded-xl"
                src="/assets/images/Cochise_New-service_Radixact-Announcement-900x900-1-1-768x768.webp"
                width={450}
                height={0}
                alt=""
              />
              <Image className="rounded-xl" src="/assets/images/cochise-welcome.png" width={500} height={0} alt="" />
            </div>
          </div>
        </div>
        <div className="w-full flex flex-wrap justify-center space-x-5 space-y-2 wow fadeInUp">
          <Link href="/radiation-oncology">
            <div className="w-[320px] h-[320px] hover:scale-105 transition-transform duration-500 bg-[url('/assets/images/cochise-radiation-oncology-768x512.webp')] bg-cover rounded-full flex items-center justify-center overflow-auto relative">
              <div className="h-full w-full rounded-full bg-gradient-to-b from-[#E3B19B82] to-[#798D90] text-center align-middle flex items-center justify-center"></div>
              <p className="text-[36px] text-center px-4 m-0 absolute text-white font-medium tracking-tight leading-10">
                Radiation Oncology
              </p>
            </div>
          </Link>
          <Link href="/medical-oncology">
            <div className="w-[320px] h-[320px] hover:scale-105 transition-transform duration-500 bg-[url('/assets/images/cochise-medical-oncology-768x512.webp')] bg-cover rounded-full flex items-center justify-center overflow-auto relative">
              <div className="h-full w-full bg-gradient-to-b from-[#E3B19B82] to-[#798D90] text-center align-middle flex items-center justify-center"></div>
              <p className="text-[36px] text-center px-4 m-0 absolute text-white font-medium tracking-tight leading-10">
                Medical Oncology
              </p>
            </div>
          </Link>
          <Link href="/skin-cancer">
            <div className="w-[320px] h-[320px] hover:scale-105 transition-transform duration-500 bg-[url('/assets/images/cochise-skin-cancer-768x512.webp')] bg-cover rounded-full flex items-center justify-center overflow-auto relative">
              <div className="h-full w-full rounded-full bg-gradient-to-b from-[#E3B19B82] to-[#798D90] text-center align-middle flex items-center justify-center"></div>
              <p className="text-[36px] text-center px-4 m-0 absolute text-white font-medium tracking-tight leading-10">
                Skin Cancer
              </p>
            </div>
          </Link>
        </div>
      </section>
      <section className="py-5 w-full flex flex-col">
        <div className="relative flex justify-center">
          <div className="w-full md:w-1/2 self-center mt-[-70px] mb-50 flex justify-center">
            <div className="bg-white h-full flex flex-col lg:flex-row flex-wrap justify-center p-4 lg:p-8 gap-3 rounded-xl shadow-xl">
              <blockquote
                className="self-center border-teal-500 pl-4 italic text-gray-800"
                style={{ borderLeft: "4px solid #eee" }}
              >
                I was diagnosed with cancer up in Tucson. The doctor was said to be best oncologist in the state.
                Problem was I needed radiation for 45 days not counting weekends and holidays.
                <br />
                <br />
                I had to tell her that that was not doable. I couldn&apos;t commute daily and I couldn&apos;t rent. I
                told her that I could get treatment of some sort in Sierra Vista. She told me that normally she would
                fight me, but only 2 Clinics in the state had this latest and greatest radiation hardware. Hers and
                Cochise Oncology in Sierra Vista.
                <br />
                <br />
                At Cochise Oncology I was introduced to Dr. Vedula. What a good man and what a great doctor. Check out
                his credentials. I am now cancer free for 9 months. It was still 45 days of treatment but no side
                effects. Plus, I would go home every day after undergoing treatment. I forget, maybe 15 minutes of
                treatment.
                <br />
                <br />
                Do yourself a favor and see Dr. Vedula.
                <br></br>
                <b>-a Cochise Oncology patient</b>
              </blockquote>
            </div>
          </div>
        </div>
        <h1 className="w-full text-center !font-light">Testimonials</h1>
        <blockquote
          className="w-full md:w-8/12 self-center border-teal-500 pl-4 italic text-gray-800"
          style={{ borderLeft: "4px solid #eee" }}
        >
          I was diagnosed with cancer up in Tucson. The doctor was said to be best oncologist in the state. Problem was
          I needed radiation for 45 days not counting weekends and holidays.
          <br />
          <br />
          I had to tell her that that was not doable. I couldn&apos;t commute daily and I couldn&apos;t rent. I told her
          that I could get treatment of some sort in Sierra Vista. She told me that normally she would fight me, but
          only 2 Clinics in the state had this latest and greatest radiation hardware. Hers and Cochise Oncology in
          Sierra Vista.
          <br />
          <br />
          At Cochise Oncology I was introduced to Dr. Vedula. What a good man and what a great doctor. Check out his
          credentials. I am now cancer free for 9 months. It was still 45 days of treatment but no side effects. Plus, I
          would go home every day after undergoing treatment. I forget, maybe 15 minutes of treatment.
          <br />
          <br />
          Do yourself a favor and see Dr. Vedula.
          <br></br>
          <b>-a Cochise Oncology patient</b>
        </blockquote>
        <Testimonials />
      </section>
      <section className="page-section bg-scroll light-content bg-[url(/assets/images/demo-modern/section-bg-3.jpeg)] bg-cover">
        <div className="bg-overlay bg-gradient-dark-alpha-2 d-none d-lg-block" />
        {/* Mobile Overlay */}
        <div className="bg-overlay bg-dark-1 opacity-09 d-lg-none" />
        {/* End Mobile Overlay */}
        <div className="container position-relative">
          <div className="row wow fadeInUp">
            <div className="col-12 col-lg-6 offset-lg-6 col-xl-6 offset-xl-6">
              <h2 className="section-title mb-40 mb-sm-30">A Cancer Treatment Center of Excellence</h2>
              <p className="">
                Get compassionate care and excellent medical services from COCHISE ONCOLOGY in Sierra Vista, Arizona. We
                are the largest full-service cancer treatment center between Albuquerque, New Mexico and Tucson,
                Arizona. Our services cover radiation treatments as well as chemotherapy, and we also have an infusion
                center. We offer support groups as well as free hospitality housing for patients undergoing treatment.
                Read on to learn more about our establishment, or reach out to us via phone or email to make an inquiry.
              </p>
              <h2 className="section-title mb-40 mb-sm-30">The Mission of Cochise Oncology</h2>
              <p className="">
                To provide excellence in cancer and patient care in a comprehensive center for the local community.
                Optimal cancer treatment places the patient first—from the patient’s first greeting with the front
                office staff to the trust they develop with the physicians and the whole treatment team. We believe our
                patients deserve and demand the very best in timely treatments, personalized care, professional
                competence, and advanced technology. We will achieve this vision by employing caring and competent staff
                with excellent training, developing multidisciplinary collaborations, and using the latest technology
                available in the most comfortable environment.
              </p>
            </div>
          </div>
        </div>
      </section>

      <section className="mt-5">
        <div className="w-full flex flex-wrap justify-center space-x-5 space-y-2 wow fadeInUp">
          <div className="w-[320px] h-[320px] hover:scale-105 transition-transform duration-500 bg-[url('https://wordpress-iggc8kgws8ok88c0w0go8kss.rankrunners.co/wp-content/uploads/2024/07/cochise-oncology-sierra-vista-arizona-hope-768x749.jpg')] bg-cover rounded-full flex overflow-auto relative">
            <div className="h-full w-full rounded-full bg-gradient-to-b from-[#E3B19B82] to-[#798D90] text-center align-middle flex items-center justify-center"></div>
            <p className="absolute text-center px-4 m-0  text-white top-[60px]">
              <span className="text-[36px] font-medium">HOPE</span>
              <br />
              <span className="text-sm tracking-tighter">
                Founded in 2006, COCHISE ONCOLOGY became a leader in cancer treatment. Hope lives here, guiding patients
                through tough times.
              </span>
            </p>
          </div>
          <div className="w-[320px] h-[320px] hover:scale-105 transition-transform duration-500 bg-[url('https://wordpress-iggc8kgws8ok88c0w0go8kss.rankrunners.co/wp-content/uploads/2024/07/cochise-oncology-sierra-vista-strength-768x652.jpg')] bg-cover rounded-full flex overflow-auto relative">
            <div className="h-full w-full bg-gradient-to-b from-[#E3B19B82] to-[#798D90] text-center align-middle flex items-center justify-center"></div>
            <p className="absolute text-center px-4 m-0  text-white top-[60px]">
              <span className="text-[36px] font-medium">STRENGTH</span>
              <br />
              <span className="text-sm tracking-tighter">
                We’ve greatly impacted Southern Arizona. Our facility is recognized for innovative and high-tech
                treatments.
              </span>
            </p>
          </div>
          <div className="w-[320px] h-[320px] hover:scale-105 transition-transform duration-500 bg-[url('https://wordpress-iggc8kgws8ok88c0w0go8kss.rankrunners.co/wp-content/uploads/2024/07/cochise-oncology-sierra-vista-courage-768x496.jpg')] bg-cover rounded-full flex overflow-auto relative">
            <div className="h-full w-full rounded-full bg-gradient-to-b from-[#E3B19B82] to-[#798D90] text-center align-middle flex items-center justify-center"></div>
            <p className="absolute text-center px-4 m-0  text-white top-[60px]">
              <span className="text-[36px] font-medium">COURAGE</span>
              <br />
              <span className="text-sm tracking-tighter">
                Fighting cancer requires immense courage. We believe no one should face this alone, so we provide whole
                patient care.
              </span>
            </p>
          </div>
        </div>
      </section>

      <section className={`mt-16 scrollSpysection ${dark ? "bg-dark-1 light-content" : ""}`} id="about">
        <div className="container position-relative">
          <div className="row mb-60 mb-xs-30">
            <div className="col-md-6">
              <h2 className="section-caption-slick mb-xs-10">Our Service</h2>
              <h3 className="section-title mb-0">Radixact® Radiation Therapy</h3>
            </div>
            <div className="col-md-5 offset-md-1 relative text-start text-md-end pt-40 pt-sm-20 local-scroll">
              {/* Decorative Dots */}
              <div
                className="decoration-2 d-none d-md-block mt-24"
                data-rellax-y=""
                data-rellax-speed="0.7"
                data-rellax-percentage="-0.2"
              >
                <Image width="103" height="223" src="/assets/images/decoration-2.svg" alt="" />
              </div>
              {/* End Decorative Dots */}

              <Link href={`/radixact`} className="link-hover-anim underline align-middle" data-link-animate="y">
                <span className="link-strong link-strong-unhovered">
                  Explore Radixact® <i className="mi-arrow-right size-18" aria-hidden="true"></i>
                </span>
                <span className="link-strong link-strong-hovered" aria-hidden="true">
                  Explore Radixact® <i className="mi-arrow-right size-18" aria-hidden="true"></i>
                </span>
              </Link>
            </div>
          </div>
          <About />
        </div>
      </section>

      <section className={`mb-5 scrollSpysection ${dark ? "bg-dark-1 light-content" : ""}`} id="contact">
        <div className="wow fadeInUp">
          <ContactBlock />
        </div>
      </section>
    </>
  );
}
